
\name{
getCellFormat
}

\alias{
getCellFormat
}

\title{
Retrieve format information from a workseet cell.
}

\description{
 
This function returns an object representing information about the
formatting and appearance characteristics of a Gnumeric worksheet
cell.  This includes information about the foreground and background
colors; font family, size and style; horizontal and vertical
alignment; border settings; etc.  This can then be used to modify and
reset values and/or used to format other cells in a similar manner.
The function getCellFormat retrieves
the setting from an actual cell and is preferred to
createCellFormat
which is purely S-based code.

}

\usage{
getCellFormat
(
row
= 
1
,
column
= 
1
,
.sheet
)
}

\arguments{
 \item{
row
}{
   
the index of the row in which the
cell of interest is located.
This is used with the column
argument to identify the cell.
This is a 1-based value, i.e. the first row is
1.

 }

 \item{
column
}{
   
the index of the column in which the
cell of interest is located.
This is used with the row
argument to identify the cell.

 }

 \item{
.sheet
}{
   
The GnumericSheetRef
instance in which to resolve the row and column
index to get the cell and extract its format information.

 }
}

\details{
This copies the formatting information
from the cell into an S object which is then
unrelated to that cell. In other words,
changes to that object will not affect the cell.
}

\value{}

\references{}

\author{
\url{http://cm.bell-labs.com/stat/duncan}
}

\note{}

\seealso{
\code{\link{}}

\url{}
}

\examples{
   
	This illustrates the output from the
getCellFormat.
This must be run from within Gnumeric
and so cannot be executed in the traditional R session.

 getCellFormat(2,1, .sheet=.sheet)

$border
$border$top
$border$top$lineType
[1] 0

$border$top$margin
begin   end width
    0     0     0

$border$top$color
$border$top$color$name
[1] ""

$border$top$color$rgb
[1] 51143 51143 51143

$border$top$color$index
NULL



$border$bottom
$border$bottom$lineType
[1] 0

$border$bottom$margin
begin   end width
    0     0     0

$border$bottom$color
$border$bottom$color$name
[1] ""

$border$bottom$color$rgb
[1] 51143 51143 51143

$border$bottom$color$index
NULL



$border$left
$border$left$lineType
[1] 0

$border$left$margin
begin   end width
    0     0     0

$border$left$color
$border$left$color$name
[1] ""

$border$left$color$rgb
[1] 51143 51143 51143

$border$left$color$index
NULL



$border$right
$border$right$lineType
[1] 0

$border$right$margin
begin   end width
    0     0     0

$border$right$color
$border$right$color$name
[1] ""

$border$right$color$rgb
[1] 51143 51143 51143

$border$right$color$index
NULL



$border$revDiagonal
$border$revDiagonal$lineType
[1] 0

$border$revDiagonal$margin
begin   end width
    0     0     0

$border$revDiagonal$color
$border$revDiagonal$color$name
[1] ""

$border$revDiagonal$color$rgb
[1] 51143 51143 51143

$border$revDiagonal$color$index
NULL



$border$diagonal
$border$diagonal$lineType
[1] 0

$border$diagonal$margin
begin   end width
    0     0     0

$border$diagonal$color
$border$diagonal$color$name
[1] ""

$border$diagonal$color$rgb
[1] 51143 51143 51143

$border$diagonal$color$index
NULL




$color
$color$foreground
$color$foreground$name
[1] ""

$color$foreground$rgb
[1]     0 65535     0

$color$foreground$index
NULL


$color$background
$color$background$name
[1] ""

$color$background$rgb
[1] 65535 65535 65535

$color$background$index
NULL
 
 
$color$pattern
$color$pattern$name
[1] ""
 
$color$pattern$rgb
[1] 0 0 0
 
$color$pattern$index
NULL
 
 
 
$pattern
[1] 0
 
$font
$font$name
[1] "Helvetica"
 
$font$dimensions
 width height
     5     10
 
 
$styles
     bold    italic underline    strike
    FALSE     FALSE     FALSE     FALSE
 
$format
[1] ""
 
$wrap
[1] FALSE
 
$align
horizontal   vertical
         1          2
 
$indent
[1] 0     

}

\keyword{ interface}
